==> haskell-tasty-quickcheck-0.9.1-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.9.1
id: tasty-quickcheck-0.9.1-G3UVkrzUHBN7SD5eqSFqrp
key: tasty-quickcheck-0.9.1-G3UVkrzUHBN7SD5eqSFqrp
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.QuickCheck
abi: 58e3bcb3d9ea98bd24f12d3c79af46de
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tasty-quickcheck-0.9.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tasty-quickcheck-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tasty-quickcheck-0.9.1
hs-libraries: HStasty-quickcheck-0.9.1-G3UVkrzUHBN7SD5eqSFqrp
depends:
    base-4.10.0.0 tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    tasty-0.11.2.5-8pVN7zY7LWxKuOoZIw4Ije
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             tasty-0.11.2.5-8pVN7zY7LWxKuOoZIw4Ije=efdb4470add4a3ba44d1c67ce2738a52
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.9.1-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.9.1
id: tasty-quickcheck-0.9.1-KHbumerx10XDZpeyTs9cRT
key: tasty-quickcheck-0.9.1-KHbumerx10XDZpeyTs9cRT
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
author: Roman Cheplyaka <roma@ro-che.info>
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.QuickCheck
abi: 7cfd7bf159c38ff391ff9ecbd887a615
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tasty-quickcheck-0.9.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/tasty-quickcheck-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tasty-quickcheck-0.9.1
hs-libraries: HStasty-quickcheck-0.9.1-KHbumerx10XDZpeyTs9cRT
depends:
    base-4.10.0.0 tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    tasty-0.11.2.5-8pVN7zY7LWxKuOoZIw4Ije
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             tasty-0.11.2.5-8pVN7zY7LWxKuOoZIw4Ije=efdb4470add4a3ba44d1c67ce2738a52
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
